==> rice-impex-server-demo-2.1.14-sql.jar: sql/oracle/KRIM_ENTITY_ENT_TYP_T.sql <==
TRUNCATE TABLE KRIM_ENTITY_ENT_TYP_T DROP STORAGE
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1','SYSTEM',TO_DATE( '20081107094902', 'YYYYMMDDHH24MISS' ),'5B1B6B919CCB6496E0404F8189D822F2',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1100','PERSON',TO_DATE( '20081113140649', 'YYYYMMDDHH24MISS' ),'5B97C50B03E06110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1101','PERSON',TO_DATE( '20081113140649', 'YYYYMMDDHH24MISS' ),'5B97C50B03E16110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1102','PERSON',TO_DATE( '20081113140649', 'YYYYMMDDHH24MISS' ),'5B97C50B03E26110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1103','PERSON',TO_DATE( '20081113140650', 'YYYYMMDDHH24MISS' ),'5B97C50B03E36110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1104','PERSON',TO_DATE( '20081113140650', 'YYYYMMDDHH24MISS' ),'5B97C50B03E46110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1105','PERSON',TO_DATE( '20081113140650', 'YYYYMMDDHH24MISS' ),'5B97C50B03E56110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1106','PERSON',TO_DATE( '20081113140650', 'YYYYMMDDHH24MISS' ),'5B97C50B03E66110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1107','PERSON',TO_DATE( '20081113140650', 'YYYYMMDDHH24MISS' ),'5B97C50B03E76110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1108','PERSON',TO_DATE( '20081113140650', 'YYYYMMDDHH24MISS' ),'5B97C50B03E86110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1109','PERSON',TO_DATE( '20081113140650', 'YYYYMMDDHH24MISS' ),'5B97C50B03E96110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1110','PERSON',TO_DATE( '20081113140651', 'YYYYMMDDHH24MISS' ),'5B97C50B03EA6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1111','PERSON',TO_DATE( '20081113140651', 'YYYYMMDDHH24MISS' ),'5B97C50B03EB6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1112','PERSON',TO_DATE( '20081113140651', 'YYYYMMDDHH24MISS' ),'5B97C50B03EC6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1113','PERSON',TO_DATE( '20081113140651', 'YYYYMMDDHH24MISS' ),'5B97C50B03ED6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1114','PERSON',TO_DATE( '20081113140651', 'YYYYMMDDHH24MISS' ),'5B97C50B03EE6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1115','PERSON',TO_DATE( '20081113140652', 'YYYYMMDDHH24MISS' ),'5B97C50B03EF6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1116','PERSON',TO_DATE( '20081113140652', 'YYYYMMDDHH24MISS' ),'5B97C50B03F06110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1117','PERSON',TO_DATE( '20081113140652', 'YYYYMMDDHH24MISS' ),'5B97C50B03F16110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1118','PERSON',TO_DATE( '20081113140652', 'YYYYMMDDHH24MISS' ),'5B97C50B03F26110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1119','PERSON',TO_DATE( '20081113140652', 'YYYYMMDDHH24MISS' ),'5B97C50B03F36110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1120','PERSON',TO_DATE( '20081113140652', 'YYYYMMDDHH24MISS' ),'5B97C50B03F46110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1121','PERSON',TO_DATE( '20081113140653', 'YYYYMMDDHH24MISS' ),'5B97C50B03F56110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1122','PERSON',TO_DATE( '20081113140653', 'YYYYMMDDHH24MISS' ),'5B97C50B03F66110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1123','PERSON',TO_DATE( '20081113140653', 'YYYYMMDDHH24MISS' ),'5B97C50B03F76110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1124','PERSON',TO_DATE( '20081113140653', 'YYYYMMDDHH24MISS' ),'5B97C50B03F86110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1125','PERSON',TO_DATE( '20081113140653', 'YYYYMMDDHH24MISS' ),'5B97C50B03F96110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1126','PERSON',TO_DATE( '20081113140653', 'YYYYMMDDHH24MISS' ),'5B97C50B03FA6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1127','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B03FB6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1128','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B03FC6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1129','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B03FD6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1130','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B03FE6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1131','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B03FF6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1132','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B04006110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1133','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B04016110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1134','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B04026110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1135','PERSON',TO_DATE( '20081113140655', 'YYYYMMDDHH24MISS' ),'5B97C50B04036110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1136','PERSON',TO_DATE( '20081113140655', 'YYYYMMDDHH24MISS' ),'5B97C50B04046110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1137','PERSON',TO_DATE( '20081113140655', 'YYYYMMDDHH24MISS' ),'5B97C50B04056110E0404F8189D85213',1)
/

==> rice-impex-server-demo-2.5.14-sql.jar: sql/oracle/KRIM_ENTITY_ENT_TYP_T.sql <==
TRUNCATE TABLE KRIM_ENTITY_ENT_TYP_T DROP STORAGE
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1','SYSTEM',TO_DATE( '20081107094902', 'YYYYMMDDHH24MISS' ),'5B1B6B919CCB6496E0404F8189D822F2',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1100','PERSON',TO_DATE( '20081113140649', 'YYYYMMDDHH24MISS' ),'5B97C50B03E06110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1101','PERSON',TO_DATE( '20081113140649', 'YYYYMMDDHH24MISS' ),'5B97C50B03E16110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1102','PERSON',TO_DATE( '20081113140649', 'YYYYMMDDHH24MISS' ),'5B97C50B03E26110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1103','PERSON',TO_DATE( '20081113140650', 'YYYYMMDDHH24MISS' ),'5B97C50B03E36110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1104','PERSON',TO_DATE( '20081113140650', 'YYYYMMDDHH24MISS' ),'5B97C50B03E46110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1105','PERSON',TO_DATE( '20081113140650', 'YYYYMMDDHH24MISS' ),'5B97C50B03E56110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1106','PERSON',TO_DATE( '20081113140650', 'YYYYMMDDHH24MISS' ),'5B97C50B03E66110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1107','PERSON',TO_DATE( '20081113140650', 'YYYYMMDDHH24MISS' ),'5B97C50B03E76110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1108','PERSON',TO_DATE( '20081113140650', 'YYYYMMDDHH24MISS' ),'5B97C50B03E86110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1109','PERSON',TO_DATE( '20081113140650', 'YYYYMMDDHH24MISS' ),'5B97C50B03E96110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1110','PERSON',TO_DATE( '20081113140651', 'YYYYMMDDHH24MISS' ),'5B97C50B03EA6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1111','PERSON',TO_DATE( '20081113140651', 'YYYYMMDDHH24MISS' ),'5B97C50B03EB6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1112','PERSON',TO_DATE( '20081113140651', 'YYYYMMDDHH24MISS' ),'5B97C50B03EC6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1113','PERSON',TO_DATE( '20081113140651', 'YYYYMMDDHH24MISS' ),'5B97C50B03ED6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1114','PERSON',TO_DATE( '20081113140651', 'YYYYMMDDHH24MISS' ),'5B97C50B03EE6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1115','PERSON',TO_DATE( '20081113140652', 'YYYYMMDDHH24MISS' ),'5B97C50B03EF6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1116','PERSON',TO_DATE( '20081113140652', 'YYYYMMDDHH24MISS' ),'5B97C50B03F06110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1117','PERSON',TO_DATE( '20081113140652', 'YYYYMMDDHH24MISS' ),'5B97C50B03F16110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1118','PERSON',TO_DATE( '20081113140652', 'YYYYMMDDHH24MISS' ),'5B97C50B03F26110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1119','PERSON',TO_DATE( '20081113140652', 'YYYYMMDDHH24MISS' ),'5B97C50B03F36110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1120','PERSON',TO_DATE( '20081113140652', 'YYYYMMDDHH24MISS' ),'5B97C50B03F46110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1121','PERSON',TO_DATE( '20081113140653', 'YYYYMMDDHH24MISS' ),'5B97C50B03F56110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1122','PERSON',TO_DATE( '20081113140653', 'YYYYMMDDHH24MISS' ),'5B97C50B03F66110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1123','PERSON',TO_DATE( '20081113140653', 'YYYYMMDDHH24MISS' ),'5B97C50B03F76110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1124','PERSON',TO_DATE( '20081113140653', 'YYYYMMDDHH24MISS' ),'5B97C50B03F86110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1125','PERSON',TO_DATE( '20081113140653', 'YYYYMMDDHH24MISS' ),'5B97C50B03F96110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1126','PERSON',TO_DATE( '20081113140653', 'YYYYMMDDHH24MISS' ),'5B97C50B03FA6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1127','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B03FB6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1128','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B03FC6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1129','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B03FD6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1130','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B03FE6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1131','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B03FF6110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1132','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B04006110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1133','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B04016110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1134','PERSON',TO_DATE( '20081113140654', 'YYYYMMDDHH24MISS' ),'5B97C50B04026110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1135','PERSON',TO_DATE( '20081113140655', 'YYYYMMDDHH24MISS' ),'5B97C50B04036110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1136','PERSON',TO_DATE( '20081113140655', 'YYYYMMDDHH24MISS' ),'5B97C50B04046110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','1137','PERSON',TO_DATE( '20081113140655', 'YYYYMMDDHH24MISS' ),'5B97C50B04056110E0404F8189D85213',1)
/
INSERT INTO KRIM_ENTITY_ENT_TYP_T (ACTV_IND,ENTITY_ID,ENT_TYP_CD,LAST_UPDT_DT,OBJ_ID,VER_NBR)
  VALUES ('Y','KR1000','PERSON',TO_DATE( '20121130172321', 'YYYYMMDDHH24MISS' ),'CFBAA6F5F0D15D07E0406E0AC31D229B',1)
/
